@@ -193,7 +193,7 @@ class DockerRunner(StepRunner):
                 tag = "latest"
             build = False
         elif "./" in step.uses:
-            img = f'{pu.sanitized_name(step.id, "step")}'
+            img = f'{pu.sanitized_name(step.id, "step")}'.lower()
             tag = f"{self._config.git_sha_short}"
             build_ctx_path = os.path.join(self._config.workspace_dir, step.uses)
         else:
@@ -248,7 +248,7 @@ class DockerRunner(StepRunner):
                 f"{self._config.workspace_dir}:/workspace",
                 "/var/run/docker.sock:/var/run/docker.sock",
             ],
-            "working_dir": "/workspace",
+            "working_dir": step.dir if step.dir else "/workspace",
             "environment": self._prepare_environment(step),
             "entrypoint": step.runs if step.runs else None,
             "detach": not self._config.pty,
