@@ -122,6 +122,19 @@ class TestHostDockerRunner(PopperTest):
             c = dr._create_container(cid, step)
             self.assertEqual(c.status, "created")
             c.remove()
+        step = Box(
+            {
+                "uses": "docker://alpine:3.9",
+                "runs": ["echo", "hello_world"],
+                "id": "KoNtAiNeR tWo",
+            },
+            default_box=True,
+        )
+        cid = pu.sanitized_name(step.id, config.wid)
+        with DockerRunner(init_docker_client=True, config=config) as dr:
+            c = dr._create_container(cid, step)
+            self.assertEqual(c.status, "created")
+            c.remove()
 
     @unittest.skipIf(os.environ.get("ENGINE", "docker") != "docker", "ENGINE != docker")
     def test_stop_running_tasks(self):
@@ -141,7 +154,12 @@ class TestHostDockerRunner(PopperTest):
     @unittest.skipIf(os.environ.get("ENGINE", "docker") != "docker", "ENGINE != docker")
     def test_get_container_kwargs(self):
         step = Box(
-            {"uses": "popperized/bin/sh@master", "args": ["ls"], "id": "one",},
+            {
+                "uses": "popperized/bin/sh@master",
+                "args": ["ls"],
+                "id": "one",
+                "dir": "/tmp/",
+            },
             default_box=True,
         )
 
@@ -176,7 +194,7 @@ class TestHostDockerRunner(PopperTest):
                         "/var/run/docker.sock:/var/run/docker.sock",
                         "/path/in/host:/path/in/container",
                     ],
-                    "working_dir": "/workspace",
+                    "working_dir": "/tmp/",
                     "environment": {"FOO": "bar"},
                     "entrypoint": None,
                     "detach": True,
@@ -207,7 +225,7 @@ class TestHostDockerRunner(PopperTest):
                         "/var/run/docker.sock:/var/run/docker.sock",
                         "/path/in/host:/path/in/container",
                     ],
-                    "working_dir": "/workspace",
+                    "working_dir": "/tmp/",
                     "environment": {"FOO": "bar"},
                     "entrypoint": None,
                     "detach": False,
