@@ -53,6 +53,16 @@ class TestScm(PopperTest):
         self.assertIsNone(scm.get_sha(None, short=8))
         self.assertIsNone(scm.get_branch(None))
 
+        # drop head commit
+        with self.assertLogs("popper", level="WARNING") as cm:
+            repo.git.update_ref("-d", "HEAD")
+            self.assertEqual(scm.get_sha(repo), None)
+            self.assertEqual(len(cm.output), 1)
+            self.assertTrue(
+                f"WARNING:popper:Could not obtain commit ID (SHA1) due to the Git repository at {repo.git_dir} being empty."
+                in cm.output[0]
+            )
+
     def test_clone(self):
         tempdir = tempfile.mkdtemp()
         tdir = os.path.join(tempdir, "test_clone")
